#!/usr/bin/env python
from __future__ import unicode_literals, division, absolute_import, print_function

import sys
import os
import webbrowser
import tempfile
import shutil
import textwrap
import time


W3C_HTML_FORM = textwrap.dedent('''\
<html>
 <body>
  <p>{0}</p>
  <p><b>{1}</b></p>
  <p>{2}</p>
  <p><input id='button' form='form' type='submit' value='Check' /></p>
  <div>
   <form id='form' enctype='multipart/form-data' action='http://jigsaw.w3.org/css-validator/validator' method='post'>
    <p><textarea name='text' rows='12' cols='70'>{3}</textarea></p>
    <input type='hidden' name='lang' value='en' />
    <input type='hidden' name='profile' value='{4}' />
   </form>
  </div>
  <script type='text/javascript'>
   function mySubmit() {{ var frm=document.getElementById('form'); frm.submit(); }}
   window.onload = function() {{ window.setTimeout(function() {{ mySubmit(); }}, {5}); }};
  </script>
 </body>
</html>''')


def run(bk):
    global W3C_HTML_FORM

    # Get preferences from json prefs
    prefs = bk.getPrefs()

    # Or use defaults if json doesn't yet exist
    if 'css_level' not in prefs:
        prefs['css_level'] = 'css3'
    if 'delay' not in prefs:
        prefs['delay'] = 3
    if 'delete_tmp_folder' not in prefs:
        prefs['delete_tmp_folder'] = True


    href = "<a href='http://jigsaw.w3.org/css-validator/'>W3C Validation Service</a>"
    arg0 = 'This plugin will send your stylesheet data to the {}.'.format(href)
    arg1 = 'This page should disappear once loaded after {} seconds.'.format(prefs['delay'])
    arg2 = 'If your browser does not have javascript enabled, click on the button below.'
    css = ''
    css_level = prefs['css_level']
    delay = prefs['delay']*1000

    tdir = tempfile.mkdtemp(prefix='CSSValidator-')
    cssfiles = 0
    message = 'Check browser for results.'
    for (ident, href) in bk.css_iter():
        cssfiles += 1
        css = bk.readfile(ident)
        if not isinstance(css, str):
            css = str(css, 'utf-8')

        # Format html
        post_form_html = W3C_HTML_FORM.format(arg0, arg1, arg2, css, css_level, delay)

        # write html to temporary file
        with tempfile.NamedTemporaryFile(mode='w+t', suffix='.html', dir=tdir, delete=False) as tfile:
            tfile.write(post_form_html)
            if sys.platform.startswith('win'):
                url = 'file:///{}'.format(tfile.name)
            else:
                url = 'file://{}'.format(tfile.name)
            # Use default browser
            webbrowser.get().open(url)

    # post some half-assed "results."
    if not cssfiles:
        message = 'No CSS files to validate.'
    bk.add_result('warning', '', '', message)

    time.sleep(3)
    if prefs['delete_tmp_folder']:
        shutil.rmtree(tdir)
        
    # Save prefs to back to json
    bk.savePrefs(prefs)
    return 0


def main():
    print ('I reached main when I should not have\n')
    return -1

if __name__ == "__main__":
    sys.exit(main())
